import { Buffer } from 'buffer';
import { getContentType, getExtension, randomStr } from "../../utils";
export class MetaplexFile {
    constructor(content, fileName, options = {}) {
        var _a, _b, _c, _d, _e;
        this.buffer = MetaplexFile.parseContent(content);
        this.fileName = fileName;
        this.displayName = (_a = options.displayName) !== null && _a !== void 0 ? _a : fileName;
        this.uniqueName = (_b = options.uniqueName) !== null && _b !== void 0 ? _b : randomStr();
        this.contentType = (_c = options.contentType) !== null && _c !== void 0 ? _c : getContentType(fileName);
        this.extension = (_d = options.extension) !== null && _d !== void 0 ? _d : getExtension(fileName);
        this.tags = (_e = options.tags) !== null && _e !== void 0 ? _e : [];
    }
    static async fromFile(file, options = {}) {
        const buffer = await file.arrayBuffer();
        return new this(buffer, file.name, options);
    }
    static fromJson(json, fileName = 'inline.json', options = {}) {
        let jsonString;
        try {
            jsonString = JSON.stringify(json);
        }
        catch (error) {
            // TODO: Custom errors.
            throw new Error('Invalid JSON');
        }
        return new this(jsonString, 'inline.json');
    }
    static parseContent(content) {
        if (content instanceof ArrayBuffer) {
            return Buffer.from(new Uint8Array(content));
        }
        return Buffer.from(content);
    }
    getTagsWithContentType() {
        if (!this.contentType) {
            return this.tags;
        }
        return [{ name: 'Content-Type', value: this.contentType }, ...this.tags];
    }
    getBytes() {
        return this.buffer.byteLength;
    }
    toBuffer() {
        return this.buffer;
    }
    toString() {
        return this.buffer.toString();
    }
    toGlobalFile() {
        return new File([this.buffer], this.fileName);
    }
}
//# sourceMappingURL=MetaplexFile.js.map