import { IdentityDriver } from './IdentityDriver';
import { GuestIdentityDriver } from './GuestIdentityDriver';
export const walletAdapterIdentity = (walletAdapter) => ({
    install(metaplex) {
        metaplex.setIdentity(new WalletAdapterIdentityDriver(metaplex, walletAdapter));
    },
});
export const walletOrGuestIdentity = (walletAdapter) => ({
    install(metaplex) {
        const identity = walletAdapter
            ? new WalletAdapterIdentityDriver(metaplex, walletAdapter)
            : new GuestIdentityDriver(metaplex);
        metaplex.setIdentity(identity);
    },
});
export class WalletAdapterIdentityDriver extends IdentityDriver {
    constructor(metaplex, walletAdapter) {
        super(metaplex);
        this.walletAdapter = walletAdapter;
    }
    get publicKey() {
        if (!this.walletAdapter.publicKey) {
            // TODO: Custom errors.
            throw new Error('Wallet adapter not initialized');
        }
        return this.walletAdapter.publicKey;
    }
    async signMessage(message) {
        if (this.walletAdapter.signMessage === undefined) {
            // TODO: Custom errors.
            throw new Error('The provided wallet adapter does not support signing messages.');
        }
        return this.walletAdapter.signMessage(message);
    }
    async signTransaction(transaction) {
        if (this.walletAdapter.signTransaction === undefined) {
            // TODO: Custom errors.
            throw new Error('The provided wallet adapter does not support signing transactions.');
        }
        return this.walletAdapter.signTransaction(transaction);
    }
    async signAllTransactions(transactions) {
        if (this.walletAdapter.signAllTransactions === undefined) {
            // TODO: Custom errors.
            throw new Error('The provided wallet adapter does not support signing transactions.');
        }
        return this.walletAdapter.signAllTransactions(transactions);
    }
    async sendTransaction(transaction, signers, options) {
        return this.walletAdapter.sendTransaction(transaction, this.metaplex.connection, {
            signers,
            ...options,
        });
    }
}
//# sourceMappingURL=WalletAdapterIdentityDriver.js.map