import cloneDeep from 'lodash.clonedeep';
import { MetaplexFile } from "../../../drivers";
import { OperationHandler, Plan } from "../../../shared";
import { walk } from "../../../utils";
export class PlanUploadMetadataOperationHandler extends OperationHandler {
    async handle(operation) {
        const metadata = operation.input;
        const files = this.getAssetsFromJsonMetadata(metadata);
        if (files.length <= 0) {
            return Plan.make().addStep({
                name: 'Upload the metadata',
                handler: () => this.uploadMetadata(metadata),
            });
        }
        return Plan.make()
            .addStep({
            name: 'Upload assets',
            handler: () => this.uploadAssets(metadata),
        })
            .addStep({
            name: 'Upload the metadata',
            handler: (input) => this.uploadMetadata(input),
        });
    }
    async uploadAssets(input) {
        const files = this.getAssetsFromJsonMetadata(input);
        const uris = await this.metaplex.storage().uploadAll(files);
        return this.replaceAssetsWithUris(input, uris);
    }
    async uploadMetadata(metadata) {
        const uri = await this.metaplex.storage().uploadJson(metadata);
        return { metadata, uri };
    }
    getAssetsFromJsonMetadata(input) {
        const files = [];
        walk(input, (walk, value) => {
            if (value instanceof MetaplexFile) {
                files.push(value);
            }
            else {
                walk(value);
            }
        });
        return files;
    }
    replaceAssetsWithUris(input, replacements) {
        const clone = cloneDeep(input);
        let index = 0;
        walk(clone, (walk, value, key, parent) => {
            if (value instanceof MetaplexFile && index < replacements.length) {
                parent[key] = replacements[index++];
            }
            walk(value);
        });
        return clone;
    }
}
//# sourceMappingURL=PlanUploadMetadataOperationHandler.js.map