import { AbortSignal } from 'abort-controller';
import { Metaplex } from '../Metaplex';
export declare type LoaderStatus = 'pending' | 'running' | 'successful' | 'failed' | 'canceled';
export interface LoaderOptions {
    failSilently?: boolean;
}
export declare abstract class Loader<T> {
    protected status: LoaderStatus;
    protected result?: T;
    protected error?: unknown;
    protected abortSignal?: AbortSignal;
    abstract handle(metaplex: Metaplex): Promise<T>;
    setAbortSignal(abortSignal: AbortSignal): this;
    reload(metaplex: Metaplex, options?: LoaderOptions): Promise<T | undefined>;
    load(metaplex: Metaplex, options?: LoaderOptions): Promise<T | undefined>;
    reset(): this;
    loadWith(preloadedResult: T): this;
    getStatus(): LoaderStatus;
    getResult(): T | undefined;
    getError(): unknown;
    isPending(): boolean;
    isLoading(): boolean;
    isLoaded(): boolean;
    wasSuccessful(): boolean;
    wasFailed(): boolean;
    wasCanceled(): boolean;
}
